@@ -2,7 +2,7 @@
 Date         : 2022-12-18 12:33:46
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2022-12-19 11:06:37
+LastEditTime : 2022-12-20 17:34:46
 LastEditors  : BDFD
 Description  : 
 FilePath     : \WES_Calculation\windspeed.py
@@ -145,7 +145,7 @@ def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
         if o2==1:
             plt.scatter(U,zw,c="blue",marker="*",s=70,edgecolors="blue",label='已知的'+str(round(atm))+'-min水上风速及对应高度')
         if o2==2:
-            section2.ex(['本例中的已知陆上风速可视为水上风速。'])
+            section2.extend(['本例中的已知陆上风速可视为水上风速。'])
         
         Uf0=k*U/math.log(zw/z0) # the initial value of friction velocity
         Uf20=Uf0# for B-D
@@ -657,7 +657,7 @@ def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
                 U1031h=att(U103,atm,60)
                 Ua3=att(U103,atm,wdu) 
                 # nn=nn+1
-                section5.extend(['. 按图II-2-1，1-h时距的U\u2081\u2080='+str(round(U1031h,3))+'m/s，而'+str(round(wdu,1))+'-min时距的U\u2081\u2080='+str(round(Ua3,3))+'m/s。'])        
+                section5.extend(['按图II-2-1，1-h时距的U\u2081\u2080='+str(round(U1031h,3))+'m/s，而'+str(round(wdu,1))+'-min时距的U\u2081\u2080='+str(round(Ua3,3))+'m/s。'])        
             else:
                 Ua3=U103
         plt.scatter(Ua3,10,c="None",marker="v",s=50,edgecolors="limegreen",label=str(round(wdu))+'-min $U_{10}$ (CEM)')
@@ -717,7 +717,7 @@ def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
     if dT==0:#20221211
         section7 += (('滨水工',str(round(Up1[10],3))),)
     else:
-        section7 += (('滨水工',str(round(Up1[10],3))+'(KEYPS)'+'    |    '+str(round(Up2[10],3))+'(B-D)'),)
+        section7 += (('滨水工',str(round(Up1[10],3))+'(KEYPS)',str(round(Up2[10],3))+'(B-D)'),)
 
     if ss1==None:
         section7 += (('JTS 145-2015',str(round(Ua1,3))),)
